@@ -1,9 +1,12 @@
-__version__ = "0.5.0"
+__version__ = "0.6.0"
 
 from .add_liquidity import LiquidityAddition  # noqa
-from .asset import Asset  # noqa
+from .asset import Asset, fetch_asset_by_index  # noqa
 from .client import PactClient  # noqa
 from .exceptions import PactSdkError  # noqa
+from .factories import *  # noqa
+from .farming import *  # noqa
+from .gas_station import GasStation, get_gas_station, set_gas_station  # noqa
 from .pool import Pool, PoolState  # noqa
 from .swap import Swap, SwapEffect  # noqa
 from .transaction_group import TransactionGroup  # noqa
